@@ -1,5 +1,5 @@
 #
-# $Id$
+# $Id: AuthTicket.pm 45 2005-06-06 04:46:10Z mschout $
 #
 
 package Apache::AuthTicket;
@@ -10,7 +10,7 @@ use vars qw($VERSION @ISA %DEFAULTS %CONFIG);
 use Apache::Constants qw(REDIRECT OK);
 use Apache::AuthCookie ();
 use DBI ();
-use Apache::AuthTicket::Util;
+use Digest::MD5 qw(md5_hex);
 
 use constant DEBUGGING => 0;
 
@@ -18,7 +18,7 @@ use constant DEBUGGING => 0;
 
 @ISA = qw(Apache::AuthCookie);
 
-$VERSION = '0.90_02';
+$VERSION = '0.40';
 
 # configuration items
 # PerlSetVar FooTicketDB  dbi:Pg:dbname=template1
@@ -40,9 +40,7 @@ $VERSION = '0.90_02';
     TicketUserTable       => 'users:usrname:passwd',
     TicketPasswordStyle   => 'cleartext',
     TicketSecretTable     => 'ticketsecrets:sec_data:sec_version',
-    TicketLoginHandler    => '/login',
-    TicketCheckIP         => 1,
-    TicketCheckBrowser    => 0
+    TicketLoginHandler    => '/login'
 );
 
 # configured items get dumped in here
@@ -100,11 +98,9 @@ sub _get_config_item {
 
     my $auth_name = $r->auth_name;
 
-    my $value = Apache::AuthTicket::Util::str_config_value(
-        $r->dir_config("${auth_name}$item"),
-           $CONFIG{$auth_name}->{$item},
-           $DEFAULTS{$item});
-
+    my $value = $r->dir_config("${auth_name}$item") ||
+           $CONFIG{$auth_name}->{$item} ||
+           $DEFAULTS{$item};
     warn "returning [$value] for $item" if DEBUGGING;
     return $value;
 }
@@ -392,22 +388,15 @@ sub make_ticket {
     my ($this, $r, $user_name) = @_;
     $this->_log_entry if DEBUGGING;
 
-    my $now     = time;
-    my $expires = $now + $this->{TicketExpires} * 60;
+    my $now      = time();
+    my $expires  = $now + $this->{TicketExpires} * 60;
+    my $ip       = $r->connection->remote_ip;
     my ($secret, $sec_version) = $this->fetch_secret();
 
-    my @fields = ($secret, $sec_version, $now, $expires, $user_name);
-
-    # only add ip if TicketCheckIP is on.
-    if ($this->_get_config_item($r, 'TicketCheckIP')) {
-        push @fields, $r->connection->remote_ip;
-    }
-
-    if ($this->_get_config_item($r, 'TicketCheckBrowser')) {
-        push @fields, Apache::AuthTicket::Util::user_agent($r);
-    }
-
-    my $hash = Apache::AuthTicket::Util::hash_for(@fields);
+    my $hash = md5_hex($secret .
+                   md5_hex(join ':', $secret, $ip, $sec_version, 
+                                      $now, $expires, $user_name)
+               );
 
     my %key = (
         'version' => $sec_version,
@@ -496,7 +485,7 @@ sub verify_ticket {
         return 0;
     }
     unless (($secret, $sec_version) = $this->fetch_secret($ticket{'version'})) {
-        # can't get server secret
+        # cat get server secret
         $r->subprocess_env(AuthTicketReason => 'missing_secret');
         return 0;
     }
@@ -509,20 +498,11 @@ sub verify_ticket {
 
     # create a new hash and verify that it matches the supplied hash
     # (prevents tampering with the cookie)
-    my @fields = ($secret, @ticket{qw(version time expires user)});
-
-    if ($this->_get_config_item($r, 'TicketCheckIP')) {
-        my $ip = $r->connection->remote_ip;
-        push @fields, $ip;
-    }
-
-    if ($this->_get_config_item($r, 'TicketCheckBrowser')) {
-        push @fields, Apache::AuthTicket::Util::user_agent($r);
-    }
-
-    warn "FIELDS: [@fields]\n" if DEBUGGING;
-
-    my $newhash = Apache::AuthTicket::Util::hash_for(@fields);
+    my $ip = $r->connection->remote_ip;
+    my $newhash = md5_hex($secret .
+                      md5_hex(join ':', $secret, $ip,
+                          @ticket{qw(version time expires user)})
+                  );
 
     unless ($newhash eq $ticket{'hash'}) {
         # ticket hash does not match (ticket tampered with?)
@@ -704,7 +684,7 @@ sub _compare_password_md5 {
     my ($this, $clearpass, $saved_pass) = @_;
     $this->_log_entry if DEBUGGING;
 
-    my $test_pass = Apache::AuthTicket::Util::hash_for($clearpass);
+    my $test_pass = md5_hex($clearpass);
     return $test_pass eq $saved_pass;
 }
 
@@ -713,7 +693,7 @@ sub _get_max_secret_version {
 
     my ($secret_table, $secret_field, $secret_version_field) =
         split(/:/, $this->{TicketSecretTable});
-
+    
     my $dbh = $this->dbh;
 
     my $query = qq{
@@ -764,7 +744,7 @@ Apache::AuthTicket - Cookie based access module.
  PerlSetVar FooDomain .foo.com
  PerlSetVar FooSecure 1
  PerlSetVar FooLoginScript /foologinform
-
+ 
  <Location /foo>
      AuthType Apache::AuthTicket
      AuthName Foo
@@ -772,14 +752,14 @@ Apache::AuthTicket - Cookie based access module.
      PerlAuthzHandler Apache::AuthTicket->authorize
      require valid-user
  </Location>
-
+ 
  <Location /foologinform>
      AuthType Apache::AuthTicket
      AuthName Foo
      SetHandler perl-script
      Perlhandler Apache::AuthTicket->login_screen
  </Location>
-
+ 
  <Location /foologin>
      AuthType Apache::AuthTicket
      AuthName Foo
@@ -1024,20 +1004,6 @@ they are successfully logged out (this is done via a redirect).
 
 Example: /logged_out_message.html
 
-=item B<TicketCheckIP> (default: on)
-
-This controlls whether or not the client IP address is included in the ticket
-hash.  The default is 'on'.  If you turn this off, then the client ip address
-will not be checked.  It is sometimes not desirable to check the client ip if
-the clients are behind load balancers and subsequent requests might come in
-from a different IP.
-
-=item B<TicketCheckBrowser> (default: off)
-
-This controlls whether or not the C<USER_AGENT> string is included in the
-ticket hash.  This can be used in conjunction with, or instead of
-C<TicketCheckIP> to prevent tampering with the ticket.
-
 =back
 
 =head2 Database Configuration
