@@ -14,11 +14,11 @@ use Apache2::Connection;
 use Apache2::ServerUtil;
 use DBI ();
 use SQL::Abstract;
-use Apache::AuthTicket::Util;
+use Digest::MD5 qw(md5_hex);
 
 use constant DEBUGGING => 0;
 
-our $VERSION = '0.90_02';
+our $VERSION = '0.40';
 
 # configuration items
 # PerlSetVar FooTicketDB  dbi:Pg:dbname=template1
@@ -40,9 +40,7 @@ our $VERSION = '0.90_02';
     TicketUserTable       => 'users:usrname:passwd',
     TicketPasswordStyle   => 'cleartext',
     TicketSecretTable     => 'ticketsecrets:sec_data:sec_version',
-    TicketLoginHandler    => '/login',
-    TicketCheckIP         => 1,
-    TicketCheckBrowser    => 0
+    TicketLoginHandler    => '/login'
 );
 
 # configured items get dumped in here
@@ -113,11 +111,9 @@ sub _get_config_item {
 
     my $auth_name = $r->auth_name;
 
-    my $value = Apache::AuthTicket::Util::str_config_value(
-        $r->dir_config("${auth_name}$item"),
-        $CONFIG{$auth_name}->{$item},
-        $DEFAULTS{$item});
-
+    my $value = $r->dir_config("${auth_name}$item") ||
+           $CONFIG{$auth_name}->{$item} ||
+           $DEFAULTS{$item};
     warn "returning [$value] for $item" if DEBUGGING;
     return $value;
 }
@@ -391,22 +387,15 @@ sub make_ticket {
     my ($this, $r, $user_name) = @_;
     $this->_log_entry if DEBUGGING;
 
-    my $now     = time;
-    my $expires = $now + $this->{TicketExpires} * 60;
+    my $now      = time();
+    my $expires  = $now + $this->{TicketExpires} * 60;
+    my $ip       = $r->connection->remote_ip;
     my ($secret, $sec_version) = $this->fetch_secret();
 
-    my @fields = ($secret, $sec_version, $now, $expires, $user_name);
-
-    # only add ip if TicketCheckIP is on.
-    if ($this->_get_config_item($r, 'TicketCheckIP')) {
-        push @fields, $r->connection->remote_ip;
-    }
-
-    if ($this->_get_config_item($r, 'TicketCheckBrowser')) {
-        push @fields, Apache::AuthTicket::Util::user_agent($r);
-    }
-
-    my $hash = Apache::AuthTicket::Util::hash_for(@fields);
+    my $hash = md5_hex($secret .
+                   md5_hex(join ':', $secret, $ip, $sec_version, 
+                                      $now, $expires, $user_name)
+               );
 
     my %key = (
         'version' => $sec_version,
@@ -496,7 +485,7 @@ sub verify_ticket {
         return 0;
     }
     unless (($secret, $sec_version) = $this->fetch_secret($ticket{'version'})) {
-        # can't get server secret
+        # cat get server secret
         $r->subprocess_env(AuthTicketReason => 'missing_secret');
         return 0;
     }
@@ -509,21 +498,11 @@ sub verify_ticket {
 
     # create a new hash and verify that it matches the supplied hash
     # (prevents tampering with the cookie)
-
-    my @fields = ($secret, @ticket{qw(version time expires user)});
-
-    if ($this->_get_config_item($r, 'TicketCheckIP')) {
-        my $ip = $r->connection->remote_ip;
-        push @fields, $ip;
-    }
-
-    if ($this->_get_config_item($r, 'TicketCheckBrowser')) {
-        push @fields, Apache::AuthTicket::Util::user_agent($r);
-    }
-
-    warn "FIELDS: [@fields]\n" if DEBUGGING;
-
-    my $newhash = Apache::AuthTicket::Util::hash_for(@fields);
+    my $ip = $r->connection->remote_ip;
+    my $newhash = md5_hex($secret .
+                      md5_hex(join ':', $secret, $ip,
+                          @ticket{qw(version time expires user)})
+                  );
 
     unless ($newhash eq $ticket{'hash'}) {
         # ticket hash does not match (ticket tampered with?)
@@ -705,7 +684,7 @@ sub _compare_password_md5 {
     my ($this, $clearpass, $saved_pass) = @_;
     $this->_log_entry if DEBUGGING;
 
-    my $test_pass = Apache::AuthTicket::Util::hash_for($clearpass);
+    my $test_pass = md5_hex($clearpass);
     return $test_pass eq $saved_pass;
 }
 
@@ -714,7 +693,7 @@ sub _get_max_secret_version {
 
     my ($secret_table, $secret_field, $secret_version_field) =
         split(/:/, $this->{TicketSecretTable});
-
+    
     my $dbh = $this->dbh;
 
     my $query = qq{
@@ -744,12 +723,12 @@ __END__
 
 =head1 NAME
 
-Apache2::AuthTicket - Cookie based access module.
+Apache::AuthTicket - Cookie based access module.
 
 =head1 SYNOPSIS
 
  # in httpd.conf
- PerlModule Apache2::AuthTicket
+ PerlModule Apache::AuthTicket
  PerlSetVar FooTicketDB DBI:mysql:database=mschout;host=testbed
  PerlSetVar FooTicketDBUser test
  PerlSetVar FooTicketDBPassword secret
@@ -765,12 +744,12 @@ Apache2::AuthTicket - Cookie based access module.
  PerlSetVar FooDomain .foo.com
  PerlSetVar FooSecure 1
  PerlSetVar FooLoginScript /foologinform
-
+ 
  <Location /foo>
-     AuthType Apache2::AuthTicket
+     AuthType Apache::AuthTicket
      AuthName Foo
-     PerlAuthenHandler Apache2::AuthTicket->authenticate
-     PerlAuthzHandler Apache2::AuthTicket->authorize
+     PerlAuthenHandler Apache::AuthTicket->authenticate
+     PerlAuthzHandler Apache::AuthTicket->authorize
      require valid-user
  </Location>
  
@@ -801,11 +780,11 @@ This module provides ticket based access control.  The theory behind this is
 similar to the system described in the eagle book.
 
 This module works using HTTP cookies to check if a user is authorized to view a
-page.  I<Apache2::AuthCookie> is used as the underlying mechanism for managing
+page.  I<Apache::AuthCookie> is used as the underlying mechanism for managing
 cookies.
 
 This module was designed to be as extensible as possible.  Its quite likely
-that you will want to create your own subclass of I<Apache2::AuthTicket> in
+that you will want to create your own subclass of I<Apache::AuthTicket> in
 order to customize various aspects of this module (show your own versions of
 the forms, override database methods etc). 
 
@@ -832,7 +811,7 @@ is incorporated into the cryptographic signature. If the ticket were
 intercepted, then an attacker would have to steal the user's IP address in
 order to be able to use the ticket.  Plus, since the tickets can expire
 automatically, we can be sure that the ticket is not valid for a long period of
-time.  Finally, by using the I<Secure> mode of I<Apache2::AuthCookie>, the
+time.  Finally, by using the I<Secure> mode of I<Apache::AuthCookie>, the
 ticket is not passed over unencrypted connections.  In order to attack this
 system, an attacker would have to exploit both the MD5 algorightm as well as
 SSL. Chances are, by the time the user could break both of these, the ticket
@@ -849,7 +828,7 @@ There are two things you must do in order to configure this module:
 
 There are two ways that this module could be configured.  Either by using a
 function call in startup.pl, or by configuring each handler explicitly in
-httpd.conf.  If you decide to mix and match using calls to Apache2::AuthTicket->configure() with directives in httpd.conf, then remember that the following precedence applies:
+httpd.conf.  If you decide to mix and match using calls to Apache::AuthTicket->configure() with directives in httpd.conf, then remember that the following precedence applies:
 
  o If a directive is specified in httpd.conf, it will be used.
  o else if a directive is specified by configure(), then the 
@@ -864,10 +843,10 @@ these is the block specifying your access restrictions.  This block should look
 somrthing like this:
 
  <Location /foo>
-     AuthType Apache2::AuthTicket
+     AuthType Apache::AuthTicket
      AuthName Foo
-     PerlAuthenHandler Apache2::AuthTicket->authenticate
-     PerlAuthzHandler Apache2::AuthTicket->authorize
+     PerlAuthenHandler Apache::AuthTicket->authenticate
+     PerlAuthzHandler Apache::AuthTicket->authorize
      require valid-user
  </Location>
 
@@ -875,37 +854,37 @@ The remaining blocks control how to display the login form, and the login and
 logout urls.  These blocks should look similar to this:
 
  <Location /foologinform>
-     AuthType Apache2::AuthTicket
+     AuthType Apache::AuthTicket
      AuthName Foo
      SetHandler perl-script
-     PerlResponseHandler Apache2::AuthTicket->login_screen
+     Perlhandler Apache::AuthTicket->login_screen
  </Location>
  
  <Location /foologin>
-     AuthType    Apache2::AuthTicket
+     AuthType    Apache::AuthTicket
      AuthName    Foo
      SetHandler  perl-script
-     PerlResponseHandler Apache2::AuthTicket->login
+     PerlHandler Apache::AuthTicket->login
  </Location>
  
  <Location /foo/logout>
-     AuthType Apache2::AuthTicket
+     AuthType Apache::AuthTicket
      AuthName Foo
      SetHandler perl-script
-     PerlResponseHandler Apache2::AuthTicket->logout
+     PerlHandler Apache::AuthTicket->logout
  </Location>
 
 =head2 Apache Configuration - startup.pl
 
-Any I<Apache2::AuthTicket> configuration items can be set in startup.pl.  You
+Any I<Apache::AuthTicket> configuration items can be set in startup.pl.  You
 can configure an AuthName like this:
 
- Apache2::AuthTicket->configure(String auth_name, *Hash config)
+ Apache::AuthTicket->configure(String auth_name, *Hash config)
 
 Note that when configuring this way you dont prefix the configuration items
 with the AuthName value like you do when using PerlSetVar directives.
 
-Note: You must still include I<Apache2::AuthCookie> configuration directives in 
+Note: You must still include I<Apache::AuthCookie> configuration directives in 
 httpd.conf when configuring the server this way.  These items include:
 
     PerlSetVar FooPath /
@@ -914,7 +893,7 @@ httpd.conf when configuring the server this way.  These items include:
     PerlSetVar FooLoginScript /foologinform
 
 example:
- Apache2::AuthTicket->configure('Foo', {
+ Apache::AuthTicket->configure('Foo', {
      TicketDB            => 'DBI:mysql:database=test;host=foo',
      TicketDBUser        => 'mschout',
      TicketDBPassword    => 'secret',
@@ -1025,20 +1004,6 @@ they are successfully logged out (this is done via a redirect).
 
 Example: /logged_out_message.html
 
-=item B<TicketCheckIP> (default: on)
-
-This controlls whether or not the client IP address is included in the ticket
-hash.  The default is 'on'.  If you turn this off, then the client ip address
-will not be checked.  It is sometimes not desirable to check the client ip if
-the clients are behind load balancers and subsequent requests might come in
-from a different IP.
-
-=item B<TicketCheckBrowser> (default: off)
-
-This controlls whether or not the C<USER_AGENT> string is included in the
-ticket hash.  This can be used in conjunction with, or instead of
-C<TicketCheckIP> to prevent tampering with the ticket.
-
 =back
 
 =head2 Database Configuration
@@ -1090,7 +1055,7 @@ This table is configured by the I<TicketSecretTable> directive.
 
 =head1 METHODS
 
-This is not a complete listing of methods contained in I<Apache2::AuthTicket>.
+This is not a complete listing of methods contained in I<Apache::AuthTicket>.
 Rather, it is a listing of methods that you might want to overload if you were
 subclassing this module.  Other methods that exist in the module are probably
 not useful to you.
@@ -1107,21 +1072,21 @@ overload this method to create your own login screen.  The log in screen only
 needs to contain a hidden field called "destination" with the contents of
 I<destination> in it, a text field named I<credential_0> and a password field
 named I<credential_1>.  You are responsible for sending the http header as well
-as the content.  See I<Apache2::AuthCookie> for the description of what each of
+as the content.  See I<Apache::AuthCookie> for the description of what each of
 these fields are for.
 
 I<action> contains the action URL for the form.  You must set the action of
 your form to this value for it to function correctly.
 
-I<Apache2::AuthTicket> also provides a mechanism to determine why the login for
+I<Apache::AuthTicket> also provides a mechanism to determine why the login for
 is being displayed.  This can be used in conjunction with
-I<Apache2::AuthCookie>'s "AuthCookieReason" setting to determine why the user is
-being asked to log in.  I<Apache2::AuthCookie> sets
+I<Apache::AuthCookie>'s "AuthCookieReason" setting to determine why the user is
+being asked to log in.  I<Apache::AuthCookie> sets
 $r->prev->subprocess_env("AuthCookieReason") to either "no_cookie" or
 "bad_cookie" when this page is loaded.  If the value is "no_cookie" then the
 user is being asked to log in for the first time, or they are logging in after
 they previously logged out.  If this value is "bad_cookie" then
-I<Apache2::AuthTicket> is asking them to re-login for some reason.  To determine
+I<Apache::AuthTicket> is asking them to re-login for some reason.  To determine
 what this reason is, you must examine
 $r->prev->subprocess_env("AuthTicketReason").  I<AuthTicketReason> can take the
 following values:
@@ -1191,8 +1156,8 @@ software, please let me know.
 The idea for this module came from the Ticket Access system in the eagle book,
 along with several ideas discussed on the mod_perl mailing list.
 
-Thanks to Ken Williams for his wonderful I<Apache2::AuthCookie> module, and for
-putting in the necessary changes to I<Apache2::AuthCookie> to make this module
+Thanks to Ken Williams for his wonderful I<Apache::AuthCookie> module, and for
+putting in the necessary changes to I<Apache::AuthCookie> to make this module
 work!
 
 =head1 AUTHOR
@@ -1201,6 +1166,6 @@ Michael Schout <mschout@gkg.net>
 
 =head1 SEE ALSO
 
-L<perl>, L<mod_perl>, L<Apache>, L<Apache2::AuthCookie>
+L<perl>, L<mod_perl>, L<Apache>, L<Apache::AuthCookie>
 
 =cut
